/**
 * Copyright 2010 Västra Götalandsregionen
 *
 *   This library is free software; you can redistribute it and/or modify
 *   it under the terms of version 2.1 of the GNU Lesser General Public
 *   License as published by the Free Software Foundation.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library; if not, write to the
 *   Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 *   Boston, MA 02111-1307  USA
 */

/**
 * 
 */
package se.vgregion.kivtools.search.svc.impl.kiv;

import java.util.List;

import se.vgregion.kivtools.search.domain.Deliverypoint;
import se.vgregion.kivtools.search.domain.Unit;
import se.vgregion.kivtools.search.exceptions.KivException;

/**
 * @author attra
 *
 */
public interface DeliverypointService {
	  /**
	   * Search the deliveryPoints of a given Unit .
	   * 
	   * @param unit - Unit domain object
	   * @return List of found deliveryPoints where the unit is registered.
	   * @throws KivException .
	   */
	  List<Deliverypoint> searchDeliveryPointsForUnit(Unit unit) throws KivException;

	  /**
	   * Search for the deliveryPoints of a unit given its hsaidentity.
	   * 
	   * @param unitHsaid - unit hsaIdentity
	   * @return List of found deliveryPoints where the unit is registered.
	   * @throws KivException .
	   */
	  List<Deliverypoint> searchDeliveryPointsForUnit(String unitHsaid) throws KivException;

	  /**
	   * Fetch delivery point object given its hsaid.
	   * 
	   * @param hsaId The hsaid of the deliveryPoint.
	   * @return The DeliveryPoint with the given hsaid.
	   * @throws KivException .
	   */
	  Deliverypoint findDeliveryPointById(String hsaId) throws KivException;

}
